@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -16,17 +16,23 @@
  */
 
 #include "message.h"
+#include "config.h"
+#include "util.h"
 #include "language.h"
 #include "lang_cfg.h"
 #include "translator.h"
+#include "translatordecoder.h"
 #include "translator_en.h"
 #if !defined(ENGLISH_ONLY)
 #include "translator_adapter.h"
 #ifdef LANG_NL
 #include "translator_nl.h"
 #endif
-#ifdef LANG_SE
-#include "translator_se.h"
+#ifdef LANG_AM
+#include "translator_am.h"
+#endif
+#ifdef LANG_SV
+#include "translator_sv.h"
 #endif
 #ifdef LANG_CZ
 #include "translator_cz.h"
@@ -34,6 +40,9 @@
 #ifdef LANG_FR
 #include "translator_fr.h"
 #endif
+#ifdef LANG_ID
+#include "translator_id.h"
+#endif
 #ifdef LANG_IT
 #include "translator_it.h"
 #endif
@@ -49,8 +58,11 @@
 #ifdef LANG_ES
 #include "translator_es.h"
 #endif
+#ifdef LANG_EO
+#include "translator_eo.h"
+#endif
 #ifdef LANG_FI
-//#include "translator_fi.h"
+#include "translator_fi.h"
 #endif
 #ifdef LANG_RU
 #include "translator_ru.h"
@@ -115,12 +127,33 @@
 #ifdef LANG_LT
 #include "translator_lt.h"
 #endif
+#ifdef LANG_LV
+#include "translator_lv.h"
+#endif
 #ifdef LANG_ZA
 #include "translator_za.h"
 #endif
+#ifdef LANG_AR
+#include "translator_ar.h"
 #endif
+#ifdef LANG_FA
+#include "translator_fa.h"
+#endif
+#ifdef LANG_MK
+#include "translator_mk.h"
+#endif
+#ifdef LANG_SC
+#include "translator_sc.h"
+#endif
+#ifdef LANG_VI
+#include "translator_vi.h"
+#endif
+#ifdef LANG_TR
+#include "translator_tr.h"
+#endif
+#endif // !ENGLISH_ONLY
 
-#define L_EQUAL(a) !stricmp(langName,a)
+#define L_EQUAL(a) !qstricmp(langName,a)
 
 Translator *theTranslator=0;
 
@@ -147,10 +180,16 @@ bool setTranslator(const char *langName)
     theTranslator=new TranslatorDutch;
   }
 #endif
-#ifdef LANG_SE
+#ifdef LANG_AM
+  else if (L_EQUAL("armenian"))
+  {
+    theTranslator=new TranslatorArmenian;
+  }
+#endif
+#ifdef LANG_SV
   else if (L_EQUAL("swedish"))
   {
-    theTranslator=new TranslatorSwedish;
+    theTranslator=new TranslatorDecoder(new TranslatorSwedish);
   }
 #endif
 #ifdef LANG_CZ
@@ -162,7 +201,13 @@ bool setTranslator(const char *langName)
 #ifdef LANG_FR  
   else if (L_EQUAL("french"))
   {
-    theTranslator=new TranslatorFrench;
+    theTranslator=new TranslatorDecoder(new TranslatorFrench);
+  }
+#endif
+#ifdef LANG_ID  
+  else if (L_EQUAL("indonesian"))
+  {
+    theTranslator=new TranslatorDecoder(new TranslatorIndonesian);
   }
 #endif
 #ifdef LANG_IT  
@@ -180,11 +225,13 @@ bool setTranslator(const char *langName)
 #ifdef LANG_JP
   else if (L_EQUAL("japanese"))
   {
-    theTranslator=new TranslatorJapanese;
+    theTranslator=new TranslatorDecoder(new TranslatorJapanese);
   }
+#endif
+#ifdef LANG_JE
   else if (L_EQUAL("japanese-en"))
   {
-    theTranslator=new TranslatorJapaneseEn;
+    theTranslator=new TranslatorDecoder(new TranslatorJapaneseEn);
   }
 #endif
 #ifdef LANG_ES
@@ -196,15 +243,13 @@ bool setTranslator(const char *langName)
 #ifdef LANG_FI
   else if (L_EQUAL("finnish"))
   {
-    //theTranslator=new TranslatorFinnish;
-    theTranslator=new TranslatorEnglish;
-    err(obsoleteMsg);
+    theTranslator=new TranslatorFinnish;
   }
 #endif
 #ifdef LANG_RU
   else if (L_EQUAL("russian"))
   {
-    theTranslator=new TranslatorRussian;
+    theTranslator=new TranslatorDecoder(new TranslatorRussian);
   }
 #endif
 #ifdef LANG_HR
@@ -228,29 +273,31 @@ bool setTranslator(const char *langName)
 #ifdef LANG_HU
   else if (L_EQUAL("hungarian"))
   {
-    theTranslator=new TranslatorHungarian;
+    theTranslator=new TranslatorDecoder(new TranslatorHungarian);
   }
 #endif
 #ifdef LANG_KR
   else if (L_EQUAL("korean"))
   {
-    theTranslator=new TranslatorKorean;
+    theTranslator=new TranslatorDecoder(new TranslatorKorean);
   }
+#endif
+#ifdef LANG_KE
   else if (L_EQUAL("korean-en"))
   {
-    theTranslator=new TranslatorKoreanEn;
+    theTranslator=new TranslatorDecoder(new TranslatorKoreanEn);
   }
 #endif
 #ifdef LANG_RO
   else if (L_EQUAL("romanian"))
   {
-    theTranslator=new TranslatorRomanian;
+    theTranslator=new TranslatorDecoder(new TranslatorRomanian);
   }
 #endif
 #ifdef LANG_SI
   else if (L_EQUAL("slovene"))
   {
-    theTranslator=new TranslatorSlovene;
+    theTranslator=new TranslatorDecoder(new TranslatorSlovene);
   }
 #endif
 #ifdef LANG_CN
@@ -262,13 +309,13 @@ bool setTranslator(const char *langName)
 #ifdef LANG_TW
   else if (L_EQUAL("chinese-traditional"))
   {
-    theTranslator=new TranslatorChinesetraditional;
+    theTranslator=new TranslatorDecoder(new TranslatorChinesetraditional);
   }
 #endif
 #ifdef LANG_NO
   else if (L_EQUAL("norwegian"))
   {
-    theTranslator=new TranslatorNorwegian;
+    theTranslator=new TranslatorDecoder(new TranslatorNorwegian);
   }
 #endif
 #ifdef LANG_BR
@@ -280,7 +327,7 @@ bool setTranslator(const char *langName)
 #ifdef LANG_DK
   else if (L_EQUAL("danish"))
   {
-    theTranslator=new TranslatorDanish;
+    theTranslator=new TranslatorDecoder(new TranslatorDanish);
   }
 #endif
 #ifdef LANG_SK
@@ -303,6 +350,12 @@ bool setTranslator(const char *langName)
 #endif
 #ifdef LANG_SR
   else if (L_EQUAL("serbian"))
+  {
+    theTranslator=new TranslatorDecoder(new TranslatorSerbian);
+  }
+#endif
+#ifdef LANG_SC
+  else if (L_EQUAL("serbian-cyrilic"))
   {
     theTranslator=new TranslatorSerbian;
   }
@@ -316,7 +369,55 @@ bool setTranslator(const char *langName)
 #ifdef LANG_LT
   else if (L_EQUAL("lithuanian"))
   {
-    theTranslator=new TranslatorLithuanian;
+    theTranslator=new TranslatorDecoder(new TranslatorLithuanian);
+  }
+#endif
+#ifdef LANG_LV
+  else if (L_EQUAL("latvian"))
+  {
+    theTranslator=new TranslatorDecoder(new TranslatorLatvian);
+  }
+#endif
+#ifdef LANG_ZA
+  else if (L_EQUAL("afrikaans"))
+  {
+    theTranslator=new TranslatorDecoder(new TranslatorAfrikaans);
+  }
+#endif
+#ifdef LANG_AR
+  else if (L_EQUAL("arabic"))
+  {
+    theTranslator=new TranslatorArabic;
+  }
+#endif
+#ifdef LANG_FA
+  else if (L_EQUAL("persian") || L_EQUAL("farsi"))
+  {
+    theTranslator=new TranslatorPersian;
+  }
+#endif
+#ifdef LANG_MK
+  else if (L_EQUAL("macedonian"))
+  {
+    theTranslator=new TranslatorMacedonian;
+  }
+#endif
+#ifdef LANG_VI
+  else if (L_EQUAL("vietnamese"))
+  {
+    theTranslator=new TranslatorVietnamese;
+  }
+#endif
+#ifdef LANG_TR
+  else if (L_EQUAL("turkish"))
+  {
+    theTranslator=new TranslatorTurkish;
+  }
+#endif
+#ifdef LANG_EO
+  else if (L_EQUAL("esperanto"))
+  {
+    theTranslator=new TranslatorEsperanto;
   }
 #endif
 #endif // ENGLISH_ONLY
@@ -327,6 +428,6 @@ bool setTranslator(const char *langName)
   }
   
   QCString msg = theTranslator->updateNeededMessage();
-  if (!msg.isEmpty()) warn_cont(msg);
+  if (!msg.isEmpty()) warn_uncond(msg);
   return TRUE;
 }
