@@ -2,7 +2,7 @@
  *
  * $Id: outputlist.h,v 1.47 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,7 +18,6 @@
 #ifndef OUTPUTLIST_H
 #define OUTPUTLIST_H
 
-#include "qtbc.h"
 #include <qlist.h>
 #include "index.h" // for IndexSections
 #include "outputgen.h"
@@ -43,6 +42,7 @@ class DotInclDepGraph;
 class DotGfxHierarchyTable;
 class SectionDict;
 class DotGroupCollaboration;
+class DocRoot;
 
 /** Class representing a list of output generators that are written to
  *  in parallel. 
@@ -70,11 +70,12 @@ class OutputList : public OutputDocInterface
     // OutputDocInterface implementation
     //////////////////////////////////////////////////
 
-    void parseDoc(const char *fileName,int startLine,
-                  Definition *ctx,MemberDef *md,const QCString &docStr,
-                  bool indexWords,bool isExample,const char *exampleName=0,
-                  bool singleLine=FALSE,bool linkFromIndex=FALSE);
-    void parseText(const QCString &textStr);
+    bool generateDoc(const char *fileName,int startLine,
+                     Definition *ctx,MemberDef *md,const QCString &docStr,
+                     bool indexWords,bool isExample,const char *exampleName=0,
+                     bool singleLine=FALSE,bool linkFromIndex=FALSE);
+    void writeDoc(DocRoot *root,Definition *ctx,MemberDef *md);
+    bool parseText(const QCString &textStr);
     
 
     void startIndexSection(IndexSections is)
@@ -363,8 +364,8 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::endContents); }
     void writeNonBreakableSpace(int num)
     { forall(&OutputGenerator::writeNonBreakableSpace,num); }
-    void startDescTable()
-    { forall(&OutputGenerator::startDescTable); }
+    void startDescTable(const char *title)
+    { forall(&OutputGenerator::startDescTable,title); }
     void endDescTable()
     { forall(&OutputGenerator::endDescTable); }
     void startDescTableTitle()
@@ -423,6 +424,8 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startParameterList,openBracket); }
     void endParameterList()
     { forall(&OutputGenerator::endParameterList); }
+    void exceptionEntry(const char* prefix,bool closeBracket)
+    { forall(&OutputGenerator::exceptionEntry,prefix,closeBracket); }
 
     void startConstraintList(const char *header) 
     { forall(&OutputGenerator::startConstraintList,header); }
@@ -471,6 +474,11 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::endFontClass); }
     void writeCodeAnchor(const char *name)
     { forall(&OutputGenerator::writeCodeAnchor,name); }
+    void setCurrentDoc(Definition *context,const char *anchor,bool isSourceFile)
+    { forall(&OutputGenerator::setCurrentDoc,context,anchor,isSourceFile); }
+    void addWord(const char *word,bool hiPriority)
+    { forall(&OutputGenerator::addWord,word,hiPriority); }
+
     void startPlainFile(const char *name)
     { 
       OutputGenerator *og=outputs->first();
@@ -489,9 +497,6 @@ class OutputList : public OutputDocInterface
         og=outputs->next();
       }
     }
-    void linkableSymbol(int,const char *,Definition *,Definition *) {}
-
-
 
   private:
     void debug();
@@ -530,6 +535,7 @@ class OutputList : public OutputDocInterface
     FORALLPROTO3(uchar,uchar,uchar);
     FORALLPROTO3(const char *,const char *,const char *);
     FORALLPROTO3(const ClassDiagram &,const char *,const char *);
+    FORALLPROTO3(Definition*,const char *,bool);
     FORALLPROTO4(SectionTypes,const char *,const char *,const char *);
     FORALLPROTO4(const char *,const char *,const char *,const char *);
     FORALLPROTO4(const char *,const char *,const char *,bool);
