@@ -2,7 +2,7 @@
  *
  * $Id: rtfgen.h,v 1.13 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2012 by Parker Waechter & Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Parker Waechter & Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -190,7 +190,7 @@ class RTFGenerator : public OutputGenerator
     void endContents() {}
     void writeNonBreakableSpace(int);
 	
-    void startDescTable();
+    void startDescTable(const char *title);
     void endDescTable();
     void startDescTableTitle();
     void endDescTableTitle();
@@ -230,6 +230,7 @@ class RTFGenerator : public OutputGenerator
     void endParameterName(bool,bool,bool) {}
     void startParameterList(bool) {}
     void endParameterList() {}
+    void exceptionEntry(const char*,bool);
 
     void startConstraintList(const char  *);
     void startConstraintParam();
@@ -257,7 +258,8 @@ class RTFGenerator : public OutputGenerator
     void endFontClass() {}
 
     void writeCodeAnchor(const char *) {}
-    void linkableSymbol(int,const char *,Definition *,Definition *) {}
+    void setCurrentDoc(Definition *,const char *,bool) {}
+    void addWord(const char *,bool) {}
 
     static bool preProcessFileInplace(const char *path,const char *name);
     
