@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -684,6 +684,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_2
         case ClassDef::Protocol:  result+="Protokoll"; break;
         case ClassDef::Category:  result+="Kategorie"; break; 
         case ClassDef::Exception:  result+="Ausnahmen"; break;
+        default: break;
       }
       result+="referenz";
       return result;
@@ -851,6 +852,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_2
         case ClassDef::Protocol:   result+="s Protokoll"; break; 
         case ClassDef::Category:   result+=" Kategorie"; break;
         case ClassDef::Exception:  result+=" Ausnahme"; break;
+        default: break;
       }
       result+=" wurde erzeugt aufgrund der Datei";
       if (single) result+=":"; else result+="en:";
@@ -1776,6 +1778,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_2
         case ClassDef::Protocol:   result+="Protokoll"; break;
         case ClassDef::Category:   result+="Kategorie"; break;
         case ClassDef::Exception:  result+="Ausnahmen"; break;
+        default: break;
       }
       if (isTemplate) result+="-Template";
       result+="-Referenz";
@@ -1844,6 +1847,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_2
         case ClassDef::Protocol:   result+="dieses Protokoll"; break;
         case ClassDef::Category:   result+="diese Kategorie"; break;
         case ClassDef::Exception:  result+="diese Ausnahme"; break;
+        default: break;
       }
       if (single)
         result+=" wurde aus der folgenden Datei erzeugt:";
@@ -2026,6 +2030,71 @@ class TranslatorGerman : public TranslatorAdapter_1_8_2
     virtual QCString trAdditionalInheritedMembers()
     { return "Weitere Geerbte Elemente"; }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.8.2
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as a tooltip for the toggle button thatappears in the
+     *  navigation tree in the HTML output when GENERATE_TREEVIEW is 
+     *  enabled. This tooltip explains the meaning of the button.
+     */
+    virtual QCString trPanelSynchronisationTooltip(bool enable)
+    {
+      QCString opt = enable ? "einzuschalten" : "auszuschalten";
+      return "Klicken um Panelsynchronisation "+opt;
+    }
+
+    /*! Used in a method of an Objective-C class that is declared in a
+     *  a category. Note that the @1 marker is required and is replaced
+     *  by a link.
+     */
+    virtual QCString trProvidedByCategory()
+    {
+      return "Bestandteil der Kategorie @1.";
+    }
+
+    /*! Used in a method of an Objective-C category that extends a class.
+     *  Note that the @1 marker is required and is replaced by a link to
+     *  the class method.
+     */
+    virtual QCString trExtendsClass()
+    {
+      return "Erweitert Klasse @1.";
+    }
+
+    /*! Used as the header of a list of class methods in Objective-C.
+     *  These are similar to static public member functions in C++.
+     */
+    virtual QCString trClassMethods()
+    {
+      return "Klassenmethoden";
+    }
+
+    /*! Used as the header of a list of instance methods in Objective-C.
+     *  These are similar to public member functions in C++.
+     */
+    virtual QCString trInstanceMethods()
+    {
+      return "Instanzmethoden";
+    }
+
+    /*! Used as the header of the member functions of an Objective-C class.
+     */
+    virtual QCString trMethodDocumentation()
+    {
+      return "Methodendokumentation";
+    }
+
+    /*! Used as the title of the design overview picture created for the
+     *  VHDL output.
+     */
+    virtual QCString trDesignOverview()
+    {
+      return "Übersicht";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+
 };
 
 #endif
